==> kdebugsettings-18.04.2.tar.xz: kdebugsettings-18.04.2/src/categorytypecombobox.h <==
/*
  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef CATEGORYTYPECOMBOBOX_H
#define CATEGORYTYPECOMBOBOX_H

#include <QComboBox>
#include "loggingcategory.h"

class CategoryTypeComboBox : public QComboBox
{
    Q_OBJECT
public:
    explicit CategoryTypeComboBox(bool customType, QWidget *parent = nullptr);
    ~CategoryTypeComboBox();

    LoggingCategory::LoggingType type() const;
    void setType(LoggingCategory::LoggingType type);
    bool loggingCategoryIsNotDefault() const;
    void setDefaultCategories(const LoggingCategory::LoggingType &defaultCategories);
    LoggingCategory::LoggingType defaultCategories() const;

    void restoreToDefault();
private:
    LoggingCategory::LoggingType mDefaultCategories = LoggingCategory::Info;
};

#endif // CATEGORYTYPECOMBOBOX_H

==> kdebugsettings-18.08.3.tar.xz: kdebugsettings-18.08.3/src/categorytypecombobox.h <==
/*
  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef CATEGORYTYPECOMBOBOX_H
#define CATEGORYTYPECOMBOBOX_H

#include <QComboBox>
#include "loggingcategory.h"

class CategoryTypeComboBox : public QComboBox
{
    Q_OBJECT
public:
    explicit CategoryTypeComboBox(bool customType, QWidget *parent = nullptr);
    ~CategoryTypeComboBox();

    Q_REQUIRED_RESULT LoggingCategory::LoggingType type() const;
    void setType(LoggingCategory::LoggingType type);
    Q_REQUIRED_RESULT bool loggingCategoryIsNotDefault() const;
    void setDefaultCategories(const LoggingCategory::LoggingType &defaultCategories);
    Q_REQUIRED_RESULT LoggingCategory::LoggingType defaultCategories() const;

    void restoreToDefault();
private:
    LoggingCategory::LoggingType mDefaultCategories = LoggingCategory::Info;
};

#endif // CATEGORYTYPECOMBOBOX_H
